#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-classes
version:              0.6.5.0
visibility:           public
id:                   quickcheck-classes-0.6.5.0-HT96UdlXEtCK6SV75dZNQp
key:                  quickcheck-classes-0.6.5.0-HT96UdlXEtCK6SV75dZNQp
license:              BSD-3-Clause
copyright:            2018 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin, chessai
homepage:             https://github.com/andrewthad/quickcheck-classes#readme
synopsis:             QuickCheck common typeclasses
description:
    This library provides QuickCheck properties to ensure
    that typeclass instances adhere to the set of laws that
    they are supposed to. There are other libraries that do
    similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing
    any new typeclasses that the user needs to learn.

    /Note:/ on GHC < 8.5, this library uses the higher-kinded typeclasses
    ('\''Data.Functor.Classes.Show1'\'', '\''Data.Functor.Classes.Eq1'\'', '\''Data.Functor.Classes.Ord1'\'', etc.),
    but on GHC >= 8.5, it uses `-XQuantifiedConstraints` to express these
    constraints more cleanly.

category:             Testing
abi:                  ec4efe26aa0ff2d9db577401381521c2
exposed:              True
exposed-modules:
    Test.QuickCheck.Classes Test.QuickCheck.Classes.IsList

hidden-modules:
    Test.QuickCheck.Classes.Alt Test.QuickCheck.Classes.Apply
    Test.QuickCheck.Classes.Euclidean Test.QuickCheck.Classes.Json
    Test.QuickCheck.Classes.MVector Test.QuickCheck.Classes.Plus
    Test.QuickCheck.Classes.Prim Test.QuickCheck.Classes.Semigroupoid
    Test.QuickCheck.Classes.Semiring Test.QuickCheck.Classes.Ring

import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-classes-0.6.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-classes-0.6.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-classes-0.6.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-classes
hs-libraries:         HSquickcheck-classes-0.6.5.0-HT96UdlXEtCK6SV75dZNQp
depends:
    QuickCheck-2.15.0.1-FUcewYgFPTwGfyjnEpPlTz
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o base-4.18.2.1 containers-0.6.7
    primitive-0.9.1.0-60b8JX0ZgoSKEjUEtmG9qp
    primitive-addr-0.1.0.3-aXyo2W1jCh1hVlpJt22YC
    quickcheck-classes-base-0.6.2.0-EzQ88DWRGdZD5NbFY812Yq
    semigroupoids-6.0.2-5GDcjReuNTUCRSvYBBcyAz
    semirings-0.7-Gn5mfJCI6vP3FECyw6ayug transformers-0.6.1.0
    vector-0.13.2.0-EFjd2WQg5nEG5BmM55CoiV

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-classes/html/quickcheck-classes.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-classes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

